@@ -32,10 +32,12 @@ use ordermap::OrderMap;
 /// element.
 ///
 /// The priority is of type P, that must implement `std::cmp::Ord`.
-/// The item is of type I, that must implement `Hash` and `Eq`
+///
+/// The item is of type I, that must implement `Hash` and `Eq`.
+///
 /// Implemented as a heap of indexes, stores the items inside an `OrderMap`
 /// to be able to retrieve them quickly.
-#[derive(Clone, Default)]
+#[derive(Clone, Default, Eq)]
 pub struct PriorityQueue<I, P>
     where I: Hash+Eq,
           P: Ord {
@@ -584,6 +586,19 @@ impl<I, P> fmt::Debug for PriorityQueue<I, P>
     }
 }
 
+use std::cmp::PartialEq;
+impl<I, P1, P2> PartialEq<PriorityQueue<I, P2>> for PriorityQueue<I, P1> 
+    where I: Hash+Eq,
+          P1: Ord,
+          P1: PartialEq<P2>,
+Option<P1>: PartialEq<Option<P2>>,
+          P2: Ord {
+    
+    fn eq(&self, other: &PriorityQueue<I, P2>) -> bool {
+        self.map == other.map
+    }
+}
+
 #[inline(always)]
 /// Compute the index of the left child of an item from its index
 fn left(i:usize) -> usize {
